==> claromentis-framework-8.13.65-b8aa1bfb.zip: web/intranet/infocapture/classes/InfocaptureEvents.php <==
<?php
namespace Claromentis\Infocapture;

$GLOBALS["__65da1b1ec2d6653e8" . "a0ab7848e536215"] = (@$GLOBALS["__65da1b1ec2" . "d6653e8a0ab7" . "848e536215"] ?: array()) + array();
class InfocaptureEvents
{
    public const IC_SLA_HOURS_CHANGE = 'infocapture.sla_hours_change';
    public const IC_TRIGGER_MODIFIED = 'infocapture.trigger_modified';
    public const IC_FIELD_PERMS_RELOCATED = 'infocapture.field_perms_relocated';
    public const IC_SLA_RULE_LIST_DELETE = 'infocapture.sla_rule_list_delete';
    public const IC_FCS_VALUE_EDIT = 'infocapture.fcs_value_edit';
    public const IC_FIELD_GROUP_MODIFIED = 'infocapture.field_group_modified';
    public const IC_SLA_STATUS_CHANGE = 'infocapture.sla_status_change';
    public const IC_FIELD_PERMS_REORDERED = 'infocapture.field_perms_reordered';
    public const IC_NOTIF_RULE_REORDER = 'infocapture.notif_rule_reorder';
    public const IC_FCS_CREATE = 'infocapture.fcs_create';
    public const IC_FIELD_PERMS_MODIFIED = 'infocapture.field_perms_modified';
    public const IC_SLA_REORDERED = 'infocapture.sla_reordered';
    public const IC_TL_EDIT = 'infocapture.tl_edit';
    public const IC_PROJECT_UPDATE = 'infocapture.project_update';
    public const IC_STATUS_UPDATE = 'infocapture.status_update';
    public const IC_STATUS_DELETE = 'infocapture.status_delete';
    public const IC_TRIGGER_CREATED = 'infocapture.trigger_created';
    public const IC_TL_DELETE = 'infocapture.tl_delete';
    public const IC_SLA_RULE_DELETE = 'infocapture.sla_rule_delete';
    public const IC_SLA_RULE_SET = 'infocapture.sla_rule_set';
    public const IC_NOTIF_RULE_CHANGE = 'infocapture.notif_rule_change';
    public const IC_DYNAMIC_RULES_REORDER = 'infocapture.dynamic_rules_reorder';
    public const IC_FIELD_PERMS_INSERT = 'infocapture.field_perms_insert';
    public const IC_FIELD_PERMS_DELETED = 'infocapture.field_perms_deleted';
    public const IC_STATUS_REORDER = 'infocapture.status_reorder';
    public const IC_TRIGGER_DELETED = 'infocapture.trigger_deleted';
    public const IC_TLIST_FIELDS_CHANGE = 'infocapture.tlist_field_change';
    public const IC_WORKFLOW_MODIFIED = 'infocapture.workflow_modified';
    public const IC_FCS_DELETE = 'infocapture.fcs_delete';
    public const IC_NOTIF_TMPL_CHANGE = 'infocapture.notif_tmpl_change';
    public const IC_DYNAMIC_RULES_CHANGE = 'infocapture.dynamic_rules_change';
    public const IC_NOTE_ADDED = 'infocapture.note_added';
    public const IC_BEFORE_NOTE_ADDED = 'infocapture.pre_note_added';
    public const IC_NOTE_EDITED = 'infocapture.note_edited';
    public const IC_BEFORE_NOTE_EDITED = 'infocapture.pre_note_edited';
    public const IC_ISSUE_DRAFT_CREATED = 'infocapture.draft_created';
    public const IC_ISSUE_DRAFT_DELETED = 'infocapture.draft_deleted';
}

==> claromentis-framework-9.6.5-177028fb.zip: web/intranet/infocapture/classes/InfocaptureEvents.php <==
<?php
namespace Claromentis\Infocapture;

$GLOBALS["__65da1b1ec2d6653e8a0ab7848e53" . "6215"] = (@$GLOBALS["__65da1b1ec2d6653e8a0ab7848e" . "536215"] ?: array()) + array();
class InfocaptureEvents
{
    public const IC_SLA_HOURS_CHANGE = 'infocapture.sla_hours_change';
    public const IC_TRIGGER_MODIFIED = 'infocapture.trigger_modified';
    public const IC_FIELD_PERMS_RELOCATED = 'infocapture.field_perms_relocated';
    public const IC_SLA_RULE_LIST_DELETE = 'infocapture.sla_rule_list_delete';
    public const IC_FCS_VALUE_EDIT = 'infocapture.fcs_value_edit';
    public const IC_FIELD_GROUP_MODIFIED = 'infocapture.field_group_modified';
    public const IC_SLA_STATUS_CHANGE = 'infocapture.sla_status_change';
    public const IC_FIELD_PERMS_REORDERED = 'infocapture.field_perms_reordered';
    public const IC_NOTIF_RULE_REORDER = 'infocapture.notif_rule_reorder';
    public const IC_FCS_CREATE = 'infocapture.fcs_create';
    public const IC_FIELD_PERMS_MODIFIED = 'infocapture.field_perms_modified';
    public const IC_SLA_REORDERED = 'infocapture.sla_reordered';
    public const IC_TL_EDIT = 'infocapture.tl_edit';
    public const IC_PROJECT_UPDATE = 'infocapture.project_update';
    public const IC_STATUS_UPDATE = 'infocapture.status_update';
    public const IC_STATUS_DELETE = 'infocapture.status_delete';
    public const IC_TRIGGER_CREATED = 'infocapture.trigger_created';
    public const IC_TL_DELETE = 'infocapture.tl_delete';
    public const IC_SLA_RULE_DELETE = 'infocapture.sla_rule_delete';
    public const IC_SLA_RULE_SET = 'infocapture.sla_rule_set';
    public const IC_NOTIF_RULE_CHANGE = 'infocapture.notif_rule_change';
    public const IC_DYNAMIC_RULES_REORDER = 'infocapture.dynamic_rules_reorder';
    public const IC_FIELD_PERMS_INSERT = 'infocapture.field_perms_insert';
    public const IC_FIELD_PERMS_DELETED = 'infocapture.field_perms_deleted';
    public const IC_STATUS_REORDER = 'infocapture.status_reorder';
    public const IC_TRIGGER_DELETED = 'infocapture.trigger_deleted';
    public const IC_TLIST_FIELDS_CHANGE = 'infocapture.tlist_field_change';
    public const IC_WORKFLOW_MODIFIED = 'infocapture.workflow_modified';
    public const IC_FCS_DELETE = 'infocapture.fcs_delete';
    public const IC_NOTIF_TMPL_CHANGE = 'infocapture.notif_tmpl_change';
    public const IC_DYNAMIC_RULES_CHANGE = 'infocapture.dynamic_rules_change';
    public const IC_NOTE_ADDED = 'infocapture.note_added';
    public const IC_BEFORE_NOTE_ADDED = 'infocapture.pre_note_added';
    public const IC_NOTE_EDITED = 'infocapture.note_edited';
    public const IC_BEFORE_NOTE_EDITED = 'infocapture.pre_note_edited';
    public const IC_ISSUE_DRAFT_CREATED = 'infocapture.draft_created';
    public const IC_ISSUE_DRAFT_DELETED = 'infocapture.draft_deleted';
}
